<template>
  <a-spin :spinning='confirmLoading'>
    <j-form-container :disabled='formDisabled'>
      <a-form-model ref='form' :model='model' :rules='validatorRules' slot='detail'>
        <a-row>
          <a-col :span='24'>
            <a-form-model-item label='所属类别' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='categoryId'>
              <a-input v-model='model.categoryId' placeholder='请输入所属类别' v-show='false'></a-input>
              <a-input :value='model.categoryName' disabled></a-input>
            </a-form-model-item>
          </a-col>
           <a-col :span='24'>
            <a-form-model-item label='编号' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='num'>
              <a-input-number v-model='model.num' placeholder='请输入编号' style='width: 100%' />
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='编码' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='code'>
              <a-input v-model='model.code' placeholder='请输入编码'></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='名称' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='name'>
              <a-input v-model='model.name' placeholder='请输入名称'></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='排序' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='sort'>
              <a-input-number v-model='model.sort' placeholder='请输入排序' style='width: 100%' />
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='启用状态' :labelCol='labelCol' :wrapperCol='wrapperCol' prop = 'enabled'>
              <j-switch   v-model='model.enabled'></j-switch>
            </a-form-model-item>
          </a-col>
         <a-col :span='24'>
            <a-form-model-item label='测试方法' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='method'>
              <a-textarea v-model='model.method' placeholder='请输入测试方法' :auto-size="{ minRows: 5, maxRows: 20 }"></a-textarea>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='判定方法' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='judge'>
              <a-textarea v-model='model.judge' placeholder='请输入判定方法' :auto-size="{ minRows: 5, maxRows: 20 }"></a-textarea>
            </a-form-model-item>
          </a-col>
          <!--
          <a-col :span='24'>
            <a-form-model-item label='关联仪器' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='insturment'>
              <a-select v-model="model.instrument"   placeholder='请选择关联仪器'>
                <a-select-option v-for="ins in instruments" :key="ins.id">
                  {{ ins.name }}
                </a-select-option>
              </a-select>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='图片说明' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='picture'>
              <j-image-upload  bizPath="lims/pic" isMultiple class="avatar-uploader" text="上传" v-model="model.picture" ></j-image-upload>
            </a-form-model-item>
          </a-col>-->
          <a-col :span='24'>
            <a-form-model-item label='是否破坏性实验' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='destructive'>
              <j-switch   v-model='model.destructive'></j-switch>
            </a-form-model-item>
          </a-col>
<!--          <a-col :span='24'>
            <a-form-model-item label='备注' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='remark'>
              <a-input v-model='model.remark' placeholder='请输入备注'></a-input>
            </a-form-model-item>
          </a-col>-->
        </a-row>
      </a-form-model>
    </j-form-container>
  </a-spin>
</template>

<script>

import { httpAction, getAction, deleteAction } from '@/api/manage'
import { validateDuplicateValue } from '@/utils/util'

export default {
  name: 'LimsTestingTypeForm',
  components: {},
  props: {
    //表单禁用
    disabled: {
      type: Boolean,
      default: false,
      required: false
    }
  },
  data() {
    return {
      model: {},
      parent: {},

      //仪器列表
      instruments:[],
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      },
      confirmLoading: false,
      validatorRules: {
        categoryId: [{ required: true, message: '鉴定类型所属类别不能为空', trigger: 'blur' }],
        code: [{ required: true, message: '鉴定类型编码不能为空', trigger: 'blur' }],
        name: [{ required: true, message: '鉴定类型名称不能为空', trigger: 'blur' }],
        sort: [{ required: true, message: '鉴定类型序不能为空', trigger: 'blur' }],
        enabled: [{ required: true, message: '鉴定类型启用状态不能为空', trigger: 'blur' }]
      },
      url: {
        add: '/lims/testing/type/add',
        edit: '/lims/testing/type/edit',
        del: '/lims/testing/type/delete',
        queryById: '/lims/testing/type/queryById',
        insturmentList: '/limsInstrument/list'
      }
    }
  },
  computed: {
    formDisabled() {
      return this.disabled
    }
  },
  created() {
    //备份model原始值
    this.modelDefault = JSON.parse(JSON.stringify(this.model))
  },
  methods: {
    add() {
      this.edit(this.modelDefault)
    },
    edit(record) {
      this.model = Object.assign({}, record)
      this.visible = true
    },
    setData(parent, model) {
      this.$refs.form.resetFields()
      this.parent = parent
      this.model = model
      this.model.enabled = 1
      this.model.categoryId = parent.categoryId
      this.model.categoryName = parent.categoryName
      //如果存在id 查询数据
      if (this.model.id) {
        this.queryTypById(this.model.id, parent)
      }
      //查询仪器列表
      this.queryInstrumentList()

    },


    /**
     * 根据id查询鉴定类型明细
     * @param id
     * @param parent
     */
    queryTypById(id, parent) {
      getAction(this.url.queryById, { id: id }).then(res => {
        console.info(res)
        if (res.success) {
          this.model = Object.assign(res.result, parent)

          console.info(this.model)
        }

      })
    },
    del(id){
      deleteAction(this.url.del,{id:id}).then(res=>{
        if(res.success){
          this.$message.success('操作成功!')
          this.$emit('ok');
        }else {
          this.$message.error('操作失败!')
        }
      })
    },
    /**
     * 查询仪器列表
     */
    queryInstrumentList() {
      getAction(this.url.insturmentList).then(res => {
        if (res.success) {
          this.instruments = res.result.records
        }
      })

    },
    submitForm() {
      const that = this
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true
          let httpurl = ''
          let method = ''
          if (!this.model.id) {
            httpurl += this.url.add
            method = 'post'
          } else {
            httpurl += this.url.edit
            method = 'put'
          }
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
          })
        }

      })
    },
    resetForm() {
      this.model = { categoryId: this.parent.categoryId, categoryName: this.parent.categoryName }
    }
  }
}
</script>